@@ -3,97 +3,86 @@ from typing import Union
 import numpy as np
 import tensorflow as tf
 import tensorflow.keras.backend as K
-from scipy.ndimage import zoom
+from scipy.ndimage.interpolation import zoom
 
 from . import ModelVisualization
-from .utils import get_num_of_steps_allowed, is_mixed_precision, listify, standardize, zoom_factor
+from .utils import get_num_of_steps_allowed, is_mixed_precision, listify, normalize, zoom_factor
 from .utils.model_modifiers import ExtractIntermediateLayerForGradcam as ModelModifier
 
 
 class Scorecam(ModelVisualization):
     """Score-CAM and Faster Score-CAM
 
-        For details on Score-CAM, see the paper:
-        [Score-CAM: Score-Weighted Visual Explanations for Convolutional Neural Networks ]
-        (https://arxiv.org/pdf/1910.01279.pdf).
-
-        For details on Faster Score-CAM, see the web site:
-        https://github.com/tabayashi0117/Score-CAM#faster-score-cam
-    Todo:
-        * Write examples
+    References:
+        * Score-CAM: Score-Weighted Visual Explanations for Convolutional Neural Networks
+          (https://arxiv.org/pdf/1910.01279.pdf)
+        * Faster Score-CAM (https://github.com/tabayashi0117/Score-CAM#faster-score-cam)
     """
+
     def __call__(self,
                  score,
                  seed_input,
-                 penultimate_layer=-1,
+                 penultimate_layer=None,
                  seek_penultimate_conv_layer=True,
                  activation_modifier=lambda cam: K.relu(cam),
                  batch_size=32,
                  max_N=None,
                  training=False,
                  expand_cam=True,
-                 standardize_cam=True) -> Union[np.ndarray, list]:
-        """Generate score-weighted class activation maps (CAM)
-            by using gradient-free visualization method.
+                 normalize_cam=True) -> Union[np.ndarray, list]:
+        """Generate score-weighted class activation maps (CAM) by using gradient-free
+        visualization method.
 
         Args:
-            score (Union[tf_keras_vis.utils.scores.Score,Callable,
-                list[tf_keras_vis.utils.scores.Score,Callable]]):
-                A Score instance or function to specify visualizing target. For example::
+            score: A :obj:`tf_keras_vis.utils.scores.Score` instance, function or a list of them.
+                For example of the Score instance to specify visualizing target::
 
                     scores = CategoricalScore([1, 294, 413])
 
-                This code above means the same with the one below::
+                The code above means the same with the one below::
 
                     score = lambda outputs: (outputs[0][1], outputs[1][294], outputs[2][413])
 
-                When the model has multiple outputs, you have to pass a list of
+                When the model has multiple outputs, you MUST pass a list of
                 Score instances or functions. For example::
 
+                    from tf_keras_vis.utils.scores import CategoricalScore, InactiveScore
                     score = [
-                        tf_keras_vis.utils.scores.CategoricalScore([1, 23]),  # For 1st output
-                        tf_keras_vis.utils.scores.InactiveScore(),            # For 2nd output
+                        CategoricalScore([1, 23]),  # For 1st model output
+                        InactiveScore(),            # For 2nd model output
                         ...
                     ]
 
-            seed_input (Union[tf.Tensor,np.ndarray,list[tf.Tensor,np.ndarray]]):
-                A tensor or a list of them to input in the model.
-                When the model has multiple inputs, you have to pass a list.
-            penultimate_layer (Union[int,str,tf.keras.layers.Layer], optional):
-                An index of the layer or the name of it or the instance itself.
-                When None, it means the same as -1.
-                If the layer specified by `penultimate_layer` is not `convolutional` layer,
-                `penultimate_layer` will work as the offset to seek `convolutional` layer.
-                Defaults to None.
-            seek_penultimate_conv_layer (bool, optional):
-                A bool that indicates whether seeks a penultimate layer or not
-                when the layer specified by `penultimate_layer` is not `convolutional` layer.
-                Defaults to True.
-            activation_modifier (Callable, optional):  A function to modify activation.
-                Defaults to `lambda cam: K.relu(cam)`.
-            batch_size (int, optional): The number of samples per batch. Defaults to 32.
-            max_N (int, optional): Setting None or under Zero is that we do NOT recommend,
-                because it takes a long time to calculate CAM.
-                When not None and over Zero of Integer, run as Faster-ScoreCAM.
-                Set larger number, need more time to visualize CAM
-                but to be able to get clearer attention images.
-                (see for details: https://github.com/tabayashi0117/Score-CAM#faster-score-cam)
-                Defaults to None.
-            training (bool, optional): A bool that indicates
-                whether the model's training-mode on or off. Defaults to False.
-            expand_cam (bool, optional): True to resize cam to the same as input image size.
-                ![Note] When True, even if the model has multiple inputs,
-                this function return only a cam value (That's, when `expand_cam` is True,
-                multiple cam images are generated from a model that has multiple inputs).
-            standardize_cam (bool, optional): When True, cam will be standardized.
+            seed_input: A tf.Tensor, :obj:`numpy.ndarray` or a list of them to input in the model.
+                That's when the model has multiple inputs, you MUST pass a list of tensors.
+            penultimate_layer: An index or name of the layer, or the tf.keras.layers.Layer
+                instance itself. When None, it means the same with `-1`. If the layer specified by
+                this option is not `convolutional` layer, `penultimate_layer` will work as the
+                offset to seek `convolutional` layer. Defaults to None.
+            seek_penultimate_conv_layer: A bool that indicates whether or not seeks a penultimate
+                layer when the layer specified by `penultimate_layer` is not `convolutional` layer.
                 Defaults to True.
+            activation_modifier: A function to modify the Class Activation Map (CAM). Defaults to
+                `lambda cam: K.relu(cam)`.
+            batch_size: The number of samples per batch. Defaults to 32.
+            max_N: When None or under Zero, run as ScoreCAM. When not None and over Zero of
+                Integer, run as Faster-ScoreCAM. Set larger number (or None), need more time to
+                visualize CAM but to be able to get clearer attention images. Defaults to None.
+            training: A bool that indicates whether the model's training-mode on or off. Defaults
+                to False.
+            expand_cam: True to resize CAM to the same as input image size. **Note!** When False,
+                even if the model has multiple inputs, return only a CAM. Defaults to True.
+            normalize_cam: When True, CAM will be normalized. Defaults to True.
+            unconnected_gradients: Specifies the gradient value returned when the given input
+                tensors are unconnected. Defaults to tf.UnconnectedGradients.NONE.
 
         Returns:
-            Union[np.ndarray,list]: The class activation maps that indicate the `seed_input` regions
-                whose change would most contribute the score value.
+            An :obj:`numpy.ndarray` or a list of them. They are the Class Activation Maps (CAMs)
+            that indicate the `seed_input` regions whose change would most contribute the score
+            value.
 
         Raises:
-            ValueError: In case of invalid arguments for `score`, or `penultimate_layer`.
+            :obj:`ValueError`: When there is any invalid arguments.
         """
         # Preparing
         scores = self._get_scores_for_multiple_outputs(score)
@@ -155,9 +144,8 @@ class Scorecam(ModelVisualization):
         masks = (np.tile(mask, (input_shape[-1], ) + (1, ) * len(map_shape)) for mask, input_shape,
                  map_shape in zip(normalized_activations, input_shapes, activation_shapes))
         # (c, samples, h, w, channels) -> (channels, samples, h, w, c)
-        masks = (np.transpose(mask,
-                              (len(mask.shape) - 1, ) + tuple(range(len(mask.shape)))[1:-1] + (0, ))
-                 for mask in masks)
+        masks = (np.transpose(mask, (len(mask.shape) - 1, ) + tuple(range(len(mask.shape)))[1:-1] +
+                              (0, )) for mask in masks)
         # Create masked inputs
         masked_seed_inputs = (np.multiply(input_template, mask)
                               for input_template, mask in zip(input_templates, masks))
@@ -190,15 +178,15 @@ class Scorecam(ModelVisualization):
             cam = activation_modifier(cam)
 
         if not expand_cam:
-            if standardize_cam:
-                cam = standardize(cam)
+            if normalize_cam:
+                cam = normalize(cam)
             return cam
 
         # Visualizing
         zoom_factors = (zoom_factor(cam.shape, X.shape) for X in seed_inputs)
         cam = [zoom(cam, factor, order=1) for factor in zoom_factors]
-        if standardize_cam:
-            cam = [standardize(x) for x in cam]
+        if normalize_cam:
+            cam = [normalize(x) for x in cam]
         if len(self.model.inputs) == 1 and not isinstance(seed_input, list):
             cam = cam[0]
         return cam
